Struct tiny_oidc_rp::IdToken[][src]

pub struct IdToken { /* fields omitted */ }
OpenID connect ID Token. More detail, see OpenID Connect Core specification 2. ID Token and 5.1 Standard Claims

Implementations

ID Token issuer

Subject Identifier. A locally unique and never reassigned identifier within the Issuer for the End-User.

End-User’s preferred e-mail address.

End-User’s full name in displayable form including all name parts, possibly including titles and suffixes, ordered according to the End-User’s locale and preferences.