Struct tiny_oidc_rp::Session[][src]

pub struct Session { /* fields omitted */ }
OpenID connect login session

Implementations

Start new OpenID connect session

Serialize session and returns (key, value) pair. Implementer should store key in browser session cookie or local storage, and store (key,value) pair in server side database. Both key and value is URL safe string

Deserialize session saved by save_session() Implementer should get session key from cookie, and load session_value from server side database.